Struct ExtWorkspaceHandleV1
pub struct ExtWorkspaceHandleV1 { /* private fields */ }wayland and Linux only.Expand description
a workspace handing a group of surfaces
A ext_workspace_handle_v1 object represents a workspace that handles a group of surfaces.
Each workspace has:
- a name, conveyed to the client with the name event
- potentially an id conveyed with the id event
- a list of states, conveyed to the client with the state event
- and optionally a set of coordinates, conveyed to the client with the coordinates event
The client may request that the compositor activate or deactivate the workspace.
Each workspace can belong to only a single workspace group. Depending on the compositor policy, there might be workspaces with the same name in different workspace groups, but these workspaces are still separate (e.g. one of them might be active while the other is not).
See also the Event enum for this interface.
Implementations
impl ExtWorkspaceHandleV1
impl ExtWorkspaceHandleV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the ext_workspace_handle_v1 object
Destroys the ext_workspace_handle_v1 object.
This request should be made either when the client does not want to use the workspace object any more or after the remove event to finalize the destruction of the object.
pub fn activate(&self)
pub fn activate(&self)
activate the workspace
Request that this workspace be activated.
There is no guarantee the workspace will be actually activated, and behaviour may be compositor-dependent. For example, activating a workspace may or may not deactivate all other workspaces in the same group.
pub fn deactivate(&self)
pub fn deactivate(&self)
deactivate the workspace
Request that this workspace be deactivated.
There is no guarantee the workspace will be actually deactivated.
pub fn assign(&self, workspace_group: &ExtWorkspaceGroupHandleV1)
pub fn assign(&self, workspace_group: &ExtWorkspaceGroupHandleV1)
assign workspace to group
Requests that this workspace is assigned to the given workspace group.
There is no guarantee the workspace will be assigned.
pub fn remove(&self)
pub fn remove(&self)
remove the workspace
Request that this workspace be removed.
There is no guarantee the workspace will be actually removed.