Struct WorkspaceCapabilities
pub struct WorkspaceCapabilities(/* private fields */);wayland and Linux only.Implementations
impl WorkspaceCapabilities
impl WorkspaceCapabilities
pub const Activate: WorkspaceCapabilities
pub const Activate: WorkspaceCapabilities
activate request is available
pub const Deactivate: WorkspaceCapabilities
pub const Deactivate: WorkspaceCapabilities
deactivate request is available
pub const Remove: WorkspaceCapabilities
pub const Remove: WorkspaceCapabilities
remove request is available
pub const Assign: WorkspaceCapabilities
pub const Assign: WorkspaceCapabilities
assign request is available
impl WorkspaceCapabilities
impl WorkspaceCapabilities
pub const fn empty() -> WorkspaceCapabilities
pub const fn empty() -> WorkspaceCapabilities
Get a flags value with all bits unset.
pub const fn all() -> WorkspaceCapabilities
pub const fn all() -> WorkspaceCapabilities
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<WorkspaceCapabilities>
pub const fn from_bits(bits: u32) -> Option<WorkspaceCapabilities>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> WorkspaceCapabilities
pub const fn from_bits_truncate(bits: u32) -> WorkspaceCapabilities
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> WorkspaceCapabilities
pub const fn from_bits_retain(bits: u32) -> WorkspaceCapabilities
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<WorkspaceCapabilities>
pub fn from_name(name: &str) -> Option<WorkspaceCapabilities>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: WorkspaceCapabilities) -> bool
pub const fn intersects(&self, other: WorkspaceCapabilities) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: WorkspaceCapabilities) -> bool
pub const fn contains(&self, other: WorkspaceCapabilities) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: WorkspaceCapabilities)
pub fn insert(&mut self, other: WorkspaceCapabilities)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: WorkspaceCapabilities)
pub fn remove(&mut self, other: WorkspaceCapabilities)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: WorkspaceCapabilities)
pub fn toggle(&mut self, other: WorkspaceCapabilities)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: WorkspaceCapabilities, value: bool)
pub fn set(&mut self, other: WorkspaceCapabilities, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: WorkspaceCapabilities,
) -> WorkspaceCapabilities
pub const fn intersection( self, other: WorkspaceCapabilities, ) -> WorkspaceCapabilities
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: WorkspaceCapabilities) -> WorkspaceCapabilities
pub const fn union(self, other: WorkspaceCapabilities) -> WorkspaceCapabilities
The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: WorkspaceCapabilities,
) -> WorkspaceCapabilities
pub const fn difference( self, other: WorkspaceCapabilities, ) -> WorkspaceCapabilities
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: WorkspaceCapabilities,
) -> WorkspaceCapabilities
pub const fn symmetric_difference( self, other: WorkspaceCapabilities, ) -> WorkspaceCapabilities
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> WorkspaceCapabilities
pub const fn complement(self) -> WorkspaceCapabilities
The bitwise negation (!) of the bits in self, truncating the result.
impl WorkspaceCapabilities
impl WorkspaceCapabilities
pub const fn iter(&self) -> Iter<WorkspaceCapabilities>
pub const fn iter(&self) -> Iter<WorkspaceCapabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<WorkspaceCapabilities>
pub const fn iter_names(&self) -> IterNames<WorkspaceCapabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.