Enum Request
#[non_exhaustive]pub enum Request<'a> {
Destroy,
Activate,
Deactivate,
Assign {
workspace_group: ExtWorkspaceGroupHandleV1,
},
Remove,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the ext_workspace_handle_v1 object
Destroys the ext_workspace_handle_v1 object.
This request should be made either when the client does not want to use the workspace object any more or after the remove event to finalize the destruction of the object.
This is a destructor, once sent this object cannot be used any longer.
Activate
activate the workspace
Request that this workspace be activated.
There is no guarantee the workspace will be actually activated, and behaviour may be compositor-dependent. For example, activating a workspace may or may not deactivate all other workspaces in the same group.
Deactivate
deactivate the workspace
Request that this workspace be deactivated.
There is no guarantee the workspace will be actually deactivated.
Assign
assign workspace to group
Requests that this workspace is assigned to the given workspace group.
There is no guarantee the workspace will be assigned.
Fields
workspace_group: ExtWorkspaceGroupHandleV1Remove
remove the workspace
Request that this workspace be removed.
There is no guarantee the workspace will be actually removed.
Implementations